@@ -414,9 +414,11 @@ static void personal_gprs_mon_check_desktop (GObject *gobject, GParamSpec *pspec
 	gboolean status;
 	g_object_get (gobject, name, &status, NULL);
 	if (status) {
-		personal_gprs_mon_update_content (self);
+		countdown_home_widget_update_content (self);
 		if (self->priv->eventID == 0) {
-			self->priv->eventID = g_timeout_add (1*1000*60, (GSourceFunc)personal_gprs_mon_update_content, self);
+			if (self->priv->refresh > 0) {
+				self->priv->eventID = g_timeout_add (self->priv->refresh*1000, (GSourceFunc)personal_gprs_mon_update_content, self);
+			}
 		}
 	} else if (self->priv->eventID != 0) {
 		g_source_remove (self->priv->eventID);
